Structs
- CmdOptions
- CmdOutput
- Output captured from a command invocation.
Functions
- options_
in_ dir_ with_ envs - Build command options with cwd + env pairs for common integration test usage.
- run
- Run a binary with arguments, capturing
code,stdout, andstderr. - run_
in_ dir - Run a binary in a specific directory.
- run_
in_ dir_ with - run_
resolved - Resolve a workspace binary by name and run it with explicit options.
- run_
resolved_ in_ dir - Resolve and run a workspace binary in a specific directory.
- run_
with